==> xfce4-diskperf-plugin_1.3.orig.tar.gz: xfce4-diskperf-plugin-1.3/panel-plugin/debug.h <==
/*
 * Copyright (c) 2003 RogerSeguin <roger_seguin@msn.com>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
#ifndef _debug_h
#define _debug_h
static char     _debug_h_id[] =
    "$Id: debug.h,v 1.2 2003/10/16 18:48:39 benny Exp $";

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <stdarg.h>

#define DEBUG	0

#define TRACE		if (!DEBUG) {} else Trace

#define TRACE_LOG	"/tmp/diskperf.log"


#ifdef __cplusplus
extern          "C" {
#endif

    int             Trace (const char *const msg, ...);
    /* Write debug information in TRACE_LOG when DEBUG is set */
    /* Return 0 on success, -1 otherwise */

#ifdef __cplusplus
}				/* extern "C" */
#endif
/*
$Log: debug.h,v $
Revision 1.2  2003/10/16 18:48:39  benny
Added support for NetBSD.

Revision 1.1.1.1  2003/10/07 03:39:22  rogerms
Initial release - v1.0

Revision 1.3  2003/09/24 10:55:08  RogerSeguin
Changed name of log file

Revision 1.2  2003/09/23 15:17:30  RogerSeguin
Use vfprintf(3)

Revision 1.1  2003/09/22 02:25:34  RogerSeguin
Initial revision

*/
#endif				/* _debug_h */

==> xfce4-diskperf-plugin_1.5.orig.tar.gz: xfce4-diskperf-plugin-1.5/panel-plugin/debug.h <==
/*
 * Copyright (c) 2003 RogerSeguin <roger_seguin@msn.com>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
#ifndef _debug_h
#define _debug_h
static char     _debug_h_id[] =
    "$Id: debug.h,v 1.3 2004/08/25 10:08:40 rogerms Exp $";

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <stdarg.h>

#ifndef DEBUG
#define DEBUG	0
#endif


#define TRACE		if (!DEBUG) {} else Trace

#define TRACE_LOG	"/tmp/diskperf.log"


#ifdef __cplusplus
extern          "C" {
#endif

    int             Trace (const char *const msg, ...);
    /* Write debug information in TRACE_LOG when DEBUG is set */
    /* Return 0 on success, -1 otherwise */

#ifdef __cplusplus
}				/* extern "C" */
#endif
/*
$Log: debug.h,v $
Revision 1.3  2004/08/25 10:08:40  rogerms
DiskPerf 1.5

Revision 1.1.1.1  2003/10/07 03:39:22  rogerms
Initial release - v1.0

Revision 1.3  2003/09/24 10:55:08  RogerSeguin
Changed name of log file

Revision 1.2  2003/09/23 15:17:30  RogerSeguin
Use vfprintf(3)

Revision 1.1  2003/09/22 02:25:34  RogerSeguin
Initial revision

*/
#endif				/* _debug_h */
